@@ -20,7 +20,6 @@
 import aeidon
 import difflib
 import gaupol
-import math
 import re
 
 from aeidon.i18n import _
@@ -158,7 +157,7 @@ class MultilineCellRenderer(Gtk.CellRendererText):
         editor.set_left_margin(self.props.xpad)
         editor.set_right_margin(self.props.xpad)
         with aeidon.util.silent(AttributeError):
-            # Top and bottom margins available since GTK+ 3.18.
+            # Top and bottom margins available since GTK 3.18.
             editor.set_top_margin(self.props.ypad)
             editor.set_bottom_margin(self.props.ypad)
         editor.gaupol_path = path
@@ -203,7 +202,7 @@ class MultilineCellRenderer(Gtk.CellRendererText):
 
     def _on_notify_text(self, *args):
         """Set markup by adding line lengths to text."""
-        # Since GTK+ 3.6, the notify::text signal seems to get
+        # Since GTK 3.6, the notify::text signal seems to get
         # emitted insanely often even if text hasn't changed at
         # all. Let's try to keep this callback as fast as possible.
         self._text = self.props.text
@@ -222,9 +221,9 @@ class MultilineCellRenderer(Gtk.CellRendererText):
         # We don't actually use the length_unit argument,
         # but do need it accounted for in memoized values.
         if not text: return ""
-        text = GLib.markup_escape_text(text)
-        if not show_lengths: return text
-        lines = text.split("\n")
+        markup = GLib.markup_escape_text(text)
+        if not show_lengths: return markup
+        lines = markup.split("\n")
         lengths = gaupol.ruler.get_lengths(text)
         return "\n".join(("{} <small>[{:d}]</small>"
                           .format(lines[i], lengths[i])
@@ -273,7 +272,7 @@ class MultilineDiffCellRenderer(MultilineCellRenderer):
 
     def _on_notify_text(self, *args):
         """Set markup by adding line lengths to text."""
-        # Since GTK+ 3.6, the notify::text signal seems to get
+        # Since GTK 3.6, the notify::text signal seems to get
         # emitted insanely often even if text hasn't changed at
         # all. Let's try to keep this callback as fast as possible.
         self._text = self.props.text
